﻿Module Module_Utils
    ' ==============================================================================================================
    '   LIST VIEW LINE-INDEX and COLUMN-INDEX FROM CURSOR POSITION
    ' ==============================================================================================================

    ' --------------------------------------------------------------------------------------------
    '   0 = first line  /  -1 = no line
    ' --------------------------------------------------------------------------------------------
    Friend Function ListView_GetLineIndex(ByVal lv As ListView) As Int32
        Dim p As Point = lv.PointToClient(Cursor.Position)
        Dim item As ListViewItem = lv.GetItemAt(p.X, p.Y)
        If item Is Nothing Then
            Return -1
        Else
            Return item.Index
        End If
    End Function

    ' --------------------------------------------------------------------------------------------
    '   0 = first column  /  -1 = no columns
    ' --------------------------------------------------------------------------------------------
    Friend Function ListView_GetColumnIndex(ByVal lv As ListView) As Int32
        Dim colx As Int32 = 0
        Dim curx As Int32 = lv.PointToClient(Cursor.Position).X
        Dim index As Int32 = -1
        Do While index < lv.Columns.Count - 1
            index += 1
            colx += lv.Columns(index).Width
            If curx < colx Then Exit Do
        Loop
        Return index
    End Function

    Friend Sub ListView_SelectLine(ByVal lv As ListView, ByVal line As Int32)
        If line >= 0 And line < lv.Items.Count Then
            lv.Items(line).Selected = True
        End If
    End Sub

    Friend Sub ListView_UnselectAllLines(ByVal lv As ListView)
        If lv.FocusedItem IsNot Nothing Then
            lv.FocusedItem.Focused = False
        End If
        For Each i As Int32 In lv.SelectedIndices
            lv.Items(i).Selected = False
        Next
    End Sub


    ' -----------------------------------------------------------------------------------------------------
    '  SOUNDS
    ' -----------------------------------------------------------------------------------------------------
    Friend Sub InitSounds()
        Dim NameSpc As String = Reflection.Assembly.GetExecutingAssembly().GetName().Name.ToString()
        Dim WavStrm As IO.Stream = Reflection.Assembly.GetExecutingAssembly().GetManifestResourceStream( _
                                                                            NameSpc + "." + "ButtonClick3.wav")
        ReDim ClickSound(CType(WavStrm.Length, Integer))
        WavStrm.Read(ClickSound, 0, Int(CType(WavStrm.Length, Integer)))
    End Sub

    Private ClickSound As Byte()
    Private Declare Function PlaySound Lib "winmm.dll" (ByVal data() As Byte, _
                                                        ByVal hMod As IntPtr, ByVal hwFlags As Integer) As Integer
    Private Const SND_ASYNC As Integer = &H1    'Play async
    Private Const SND_MEMORY As Integer = &H4   'Play in memory

    Friend Sub PlayClickSound()
        PlaySound(ClickSound, IntPtr.Zero, SND_ASYNC Or SND_MEMORY)
    End Sub

End Module


Public Class VirtualKeyboard
    Private Declare Function keybd_event Lib "user32.dll" (ByVal bVk As Byte, _
                                                           ByVal bScan As Byte, _
                                                           ByVal dwFlags As Integer, _
                                                           ByVal dwExtraInfo As Integer) As UInteger

    Public Shared Sub KeyDown(ByVal key As System.Windows.Forms.Keys)
        keybd_event(CType(key, Byte), 0, 0, 0)
    End Sub

    Public Shared Sub KeyUp(ByVal key As System.Windows.Forms.Keys)
        keybd_event(CType(key, Byte), 0, 2, 0)
    End Sub
End Class
